/*
 * Student License - for use by students to meet course requirements and
 * perform academic research at degree granting institutions only.  Not
 * for government, commercial, or other organizational use.
 *
 * combine_vector_elements.h
 *
 * Code generation for function 'combine_vector_elements'
 *
 */

#ifndef COMBINE_VECTOR_ELEMENTS_H
#define COMBINE_VECTOR_ELEMENTS_H

/* Include files */
#include <cmath>
#include <math.h>
#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include "rt_nonfinite.h"
#include "rtwtypes.h"
//#include "omp.h"
#include "MAVEfast_types.h"

/* Function Declarations */
extern void combine_vector_elements(const emxArray_real_T *x, emxArray_real_T *y);

#endif

/* End of code generation (combine_vector_elements.h) */
